@@ -740,6 +740,7 @@ public:
 				timeout_t answer_timer, hunt_timer;
 				Line *select;
 				unsigned index;
+				time_t start;
 				char digits[64];
 			}	join;
 
@@ -1974,6 +1975,8 @@ private:
 protected:
 	virtual const char *submit(const char **data);
 
+	virtual void billing(BayonneSession *p, BayonneSession *c, time_t start);
+
 	virtual ScriptCompiler *compiler(void);
 
 	BayonneSession *session(ScriptInterp *interp);
@@ -1988,6 +1991,8 @@ public:
 	static const char *submitRequest(const char **data);
 
 	static ScriptCompiler *getCompiler(void);
+
+	static void reportBilling(BayonneSession *p, BayonneSession *c, time_t start);
 };
 
 /**
