@@ -1284,12 +1284,22 @@ bool BayonneSession::stateJoin(Event *event)
                 setSymbol("script.error", "none");
 		time(&state.join.start);
                 return true; 
+	case CALL_HOLD:
+		if(holding)
+			return false;
+		holding = true;
 	case AUDIO_DISCONNECT:
+		if(!peer)
+			return true;
 		memcpy(&hold_event, event, sizeof(hold_event));
 		hold_event.id = PEER_DISCONNECT;
 		peer->queEvent(&hold_event);
 		return true;
+	case CALL_NOHOLD:
+		holding = false;
         case AUDIO_RECONNECT:
+		if(!peer)
+			return true;
                 memcpy(&hold_event, event, sizeof(hold_event));
                 hold_event.id = PEER_RECONNECT;
                 peer->queEvent(&hold_event);
@@ -1297,6 +1307,8 @@ bool BayonneSession::stateJoin(Event *event)
 	case DTMF_KEYDOWN:
 		if(!state.join.dtmf)
 			return true;
+		if(!peer)
+			return true;
 		memcpy(&dtmf_event, event, sizeof(dtmf_event));
 		dtmf_event.id = DTMF_GENDOWN;
 		peer->queEvent(&dtmf_event);
@@ -1307,6 +1319,8 @@ bool BayonneSession::stateJoin(Event *event)
 			pid = PART_EXITING;
 			break;
 		}
+		if(!peer)
+			break;
 		memcpy(&dtmf_event, event, sizeof(dtmf_event));
 		dtmf_event.id = DTMF_GENUP;
 		peer->queEvent(&dtmf_event);
@@ -1589,6 +1603,8 @@ bool BayonneSession::stateIdle(Event *event)
 	case STOP_SCRIPT:
 	case EXIT_THREAD:
 	case MAKE_IDLE:
+	case CALL_HOLD:
+	case CALL_NOHOLD:
 		return true;
 	case RING_ON:
 		type = INCOMING;
@@ -2039,9 +2055,12 @@ bool BayonneSession::stateRunning(Event *event)
 			return true;
 		}
 	case TIMER_EXPIRED:
-		clrAudio();
-		step();
-		check();
+		if(!holding)
+		{
+			clrAudio();
+			step();
+			check();
+		}
 		if(state.handler == &BayonneSession::stateRunning)
 			startTimer(step_timer);
 		else
@@ -2083,6 +2102,7 @@ bool BayonneSession::stateHangup(Event *event)
 	{
 		decActiveCalls();
 		BayonneService::detach(this);
+		holding = false;
 	}
 
         if(enterHangup(event))
@@ -2100,6 +2120,8 @@ bool BayonneSession::stateHangup(Event *event)
 	case STOP_DISCONNECT:
 	case STOP_SCRIPT:
 	case EXIT_THREAD:
+	case CALL_HOLD:
+	case CALL_NOHOLD:
 	case MAKE_IDLE:		// ignore since already going idle
 		return true;
 
@@ -2238,6 +2260,19 @@ bool BayonneSession::enterCommon(Event *event)
 	case SYSTEM_DOWN:
 		return true;
 
+	case CALL_HOLD:
+		if(offhook && !holding)
+			holding = true;
+		else
+			return false;
+		return true;
+	case CALL_NOHOLD:
+		if(holding)
+			holding = false;
+		else
+			return false;
+		return true;
+
 	case MAKE_IDLE:
 		if(offhook)
 		{
