@@ -1156,6 +1156,16 @@ void Driver::publishUpdate(eXosip_event_t *sevent, Registry *reg)
 	if(online && presence)
 		reg->traffic->presence = SIPTraffic::P_ONLINE;
 }
+
+void Driver::requestOptions(eXosip_event_t *sevent)
+{
+	osip_message_t *reply = NULL;
+
+	eXosip_lock();
+	if(eXosip_options_build_answer(sevent->tid, 200, &reply) == 0)
+		eXosip_options_send_answer(sevent->tid, 200, reply);
+	eXosip_unlock();
+}
 	
 void Driver::registerRequest(eXosip_event_t *sevent)
 {
@@ -1164,6 +1174,7 @@ void Driver::registerRequest(eXosip_event_t *sevent)
 	osip_contact_t *contact = NULL;
 	osip_authorization_t *auth = NULL;
 	osip_header_t *exp = NULL;
+	osip_uri_param_t *param = NULL;
 	const char *realm = getLast("realm");
 	const char *nonce = getLast("nonce");
 	char buf[256];
@@ -1256,8 +1267,13 @@ sip200:
 		goto answer200;
 	}
 	osip_message_get_expires(sevent->request, 0, &exp);
+	if(contact)
+		osip_contact_param_get_byname(contact, "expires", &param);
+
 	if(exp && exp->hvalue)
 		pos = osip_atoi(exp->hvalue);
+	else if(param && param->gvalue)
+		pos = osip_atoi(param->gvalue);
 	else
 		pos = 600;
 
@@ -1838,6 +1854,7 @@ void Driver::run(void)
 	unsigned short sinstance;
 	time_t now;
 	time_t last = 0;
+	bool inactive;
 
 	Bayonne::waitLoaded();
 
@@ -2235,6 +2252,8 @@ killit:
 				break;
 			if(MSG_IS_REGISTER(sevent->request))
 				registerRequest(sevent);
+			else if(MSG_IS_OPTIONS(sevent->request))
+				requestOptions(sevent);
 			else if(MSG_IS_PUBLISH(sevent->request))
 			{
 				osip_to_to_str(sevent->request->to, &local_uri);
@@ -2324,6 +2343,8 @@ killit:
 			conn = eXosip_get_audio_connection(remote_sdp);
 			remote_media = eXosip_get_audio_media(remote_sdp);
 
+			inactive = false;
+
 			if(!remote_media)
 			{
 				eXosip_lock();
@@ -2352,6 +2373,11 @@ killit:
 					if(!attr)
 						continue;
 
+					tmp = attr->a_att_field;
+					if(tmp && !stricmp(tmp, "sendonly"))
+						inactive = true;
+					else if(tmp && !stricmp(tmp, "inactive"))
+						inactive = true;
 					tmp = attr->a_att_value;
 					if(!tmp)
 						continue;
@@ -2414,8 +2440,10 @@ killit:
                                 addString(sdp, 4096, cbuf);
                         }
 			memset(&event, 0, sizeof(event));
-			if(*conn->c_addr == '0')
-				event.id = AUDIO_DISCONNECT;
+			if(*conn->c_addr == '0' || inactive)
+				event.id = CALL_HOLD;
+			else if(session->holding)
+				event.id = CALL_NOHOLD;
 			else
 				event.id = AUDIO_RECONNECT;
 			session->enter();
