@@ -197,6 +197,7 @@ public:
 
 	SIPTraffic *getTraffic(const char *id);
 
+	void requestOptions(eXosip_event_t *sevent);
 	void requestAuth(eXosip_event_t *sevent);
 	bool getRegistry(eXosip_event_t *sevent, Registry **reg, ScriptImage *img);
 	void publishRequest(eXosip_event_t *sevent, const char *target);
@@ -387,6 +388,9 @@ public:
 
 	unsigned char peerEncoding(BayonneSession *s);
 	unsigned char peerEvents(BayonneSession *s);
+
+	void requestHold(void);
+	void requestJoin(void);
 };
 
 }
