@@ -39,8 +39,7 @@ TimerPort()
 	dtmf_inband = Driver::sip.dtmf_inband;
 	dtmf_sipinfo = false;
 
-	rtp_flag = update_pos = false;
-	reconnecting = false;
+	rtp_flag = update_pos = reconnecting = false;
 
 	peer_buffer = NULL;
 	peer_codec = NULL;
