@@ -54,13 +54,15 @@ void Session::help(void)
 {
 	*tcp() << "bye - disconnect session" << endl;
 	*tcp() << "calls [sid..] - display active calls" << endl;
+	*tcp() << "diskstat - show disk status" << endl;
 	*tcp() << "drivers [names..] - display loaded drivers" << endl;
 	*tcp() << "global id cmd [val] - manipulate global" << endl;
+	*tcp() << "hold sid - hold a running session" << endl;
 	*tcp() << "mon state|all timeslots.. - enable state monitoring" << endl;
 	*tcp() << "nomon timeslots.. - disable state monitoring" << endl;
         *tcp() << "reg - display protocol registrations" << endl;
 	*tcp() << "reload - reload script configuration" << endl;
-	*tcp() << "diskstat - show disk status" << endl;
+	*tcp() << "resume sid - resume from hold state" << endl;
 	*tcp() << "shutdown - shutdown server" << endl;
 	*tcp() << "spans - list active spans in server" << endl;
 	*tcp() << "start dial script [num [cid]] - start a script running" << endl;
@@ -598,6 +600,47 @@ void Session::run(void)
 				else
 					*tcp() << "*** stop ignored" << endl;
 			}
+			else if(!stricmp(*argv, "hold"))
+			{
+				if(!argv[1])
+				{
+					*tcp() << "*** missing session id" << endl;
+					goto skip;
+				}
+				session = getSid(argv[1]);
+				if(!session)
+				{
+					*tcp() << "*** invalid or unknown call session" << endl;
+					goto skip;
+				}
+				memset(&event, 0, sizeof(event));
+				event.id = CALL_HOLD;
+				if(session->postEvent(&event))
+					*tcp() << "script held" << endl;
+				else
+					*tcp() << "*** hold ignored" << endl;
+			}
+			else if(!stricmp(*argv, "resume"))
+			{
+				if(!argv[1])
+				{
+					*tcp() << "*** missing session id" << endl;
+					goto skip;
+				}
+				session = getSid(argv[1]);
+				if(!session)
+				{
+					*tcp() << "*** invalid or unknown call session" << endl;
+					goto skip;
+				}
+				memset(&event, 0, sizeof(event));
+				event.id = CALL_NOHOLD;
+				if(session->postEvent(&event))
+					*tcp() << "script resumed" << endl;
+				else
+					*tcp() << "*** resume ignored" << endl;
+			}
+
 			else if(!strnicmp(*argv, "stat", 4))
 				*tcp() << status << endl;
 			else if(!stricmp(*argv, "uptime"))
