@@ -80,6 +80,8 @@ protected:
 	void xmlReload(void);
 	void xmlStop(void);
 	void xmlStart(void);
+	void xmlHold(void);
+	void xmlResume(void);
 	void xmlShutdown(void);
 
 	char *urlDecode(char *source);
