@@ -313,6 +313,12 @@ timeout:
 	if(!stricmp(req_path, "stop.xml"))
 		xmlStop();
 
+	if(!stricmp(req_path, "hold.xml"))
+		xmlHold();
+
+	if(!stricmp(req_path, "resume.xml"))
+		xmlResume();
+
 	if(!stricmp(req_path, "start.xml"))
 		xmlStart();
 
